@@ -3,14 +3,15 @@ import logging
 import os
 from concurrent.futures import Executor
 from typing import (
-    Any, Callable, Coroutine, MutableSet, Optional, TypeVar, Union,
+    Any, Callable, Coroutine, Iterable, MutableSet, Optional, TypeVar, Union,
 )
 from weakref import WeakSet
 
 import aiomisc_log
 from aiomisc_log import LogLevel
 
-from .compat import event_loop_policy, set_current_loop
+from ._context_vars import EVENT_LOOP, StrictContextVar
+from .compat import event_loop_policy, final
 from .context import Context, get_context
 from .log import LogFormat, basic_config
 from .service import Service
@@ -39,6 +40,7 @@ def _get_env_convert(name: str, converter: Callable[..., T], default: T) -> T:
     return converter(value)
 
 
+@final
 class Entrypoint:
     DEFAULT_LOG_LEVEL: str = os.getenv(
         "AIOMISC_LOG_LEVEL", LogLevel.default(),
@@ -46,6 +48,9 @@ class Entrypoint:
     DEFAULT_LOG_FORMAT: str = os.getenv(
         "AIOMISC_LOG_FORMAT", LogFormat.default(),
     )
+    DEFAULT_LOG_DATE_FORMAT: Optional[str] = os.getenv(
+        "AIOMISC_LOG_DATE_FORMAT"
+    )
 
     DEFAULT_AIOMISC_DEBUG: bool = _get_env_bool("AIOMISC_DEBUG", "0")
     DEFAULT_AIOMISC_LOG_CONFIG: bool = _get_env_bool(
@@ -69,18 +74,24 @@ class Entrypoint:
     POST_START = Signal()
     PRE_STOP = Signal()
 
+    @classmethod
+    def get_current(cls) -> "Entrypoint":
+        return CURRENT_ENTRYPOINT.get()
+
     async def _start(self) -> None:
         if self.log_config:
             basic_config(
                 level=self.log_level,
                 log_format=self.log_format,
+                date_format=self.log_date_format,
                 buffered=self.log_buffering,
                 loop=self.loop,
                 buffer_size=self.log_buffer_size,
                 flush_interval=self.log_flush_interval,
             )
 
-        set_current_loop(self.loop)
+        CURRENT_ENTRYPOINT.set(self)
+        EVENT_LOOP.set(self.loop)
 
         for signal in (
             self.pre_start, self.post_stop,
@@ -88,13 +99,10 @@ class Entrypoint:
         ):
             signal.freeze()
 
-        await self.pre_start.call(entrypoint=self, services=self.services)
-
-        await asyncio.gather(
-            *[self._start_service(svc) for svc in self.services],
-        )
-
-        await self.post_start.call(entrypoint=self, services=self.services)
+        services = self.services
+        await self.pre_start.call(entrypoint=self, services=services)
+        await asyncio.gather(*[self._start_service(svc) for svc in services])
+        await self.post_start.call(entrypoint=self, services=services)
 
     def __init__(
         self, *services: Service,
@@ -104,15 +112,16 @@ class Entrypoint:
         log_format: Union[str, LogFormat] = DEFAULT_LOG_FORMAT,
         log_buffering: bool = DEFAULT_AIOMISC_BUFFERING,
         log_buffer_size: int = DEFAULT_AIOMISC_BUFFER_SIZE,
+        log_date_format: Optional[str] = DEFAULT_LOG_DATE_FORMAT,
         log_flush_interval: float = DEFAULT_AIOMISC_LOG_FLUSH,
         log_config: bool = DEFAULT_AIOMISC_LOG_CONFIG,
         policy: asyncio.AbstractEventLoopPolicy = event_loop_policy,
         debug: bool = DEFAULT_AIOMISC_DEBUG,
     ):
 
-        """
+        """ Creates a new Entrypoint
 
-        :param debug: set debug to event loop
+        :param debug: set debug to event-loop
         :param loop: loop
         :param services: Service instances which will be starting.
         :param pool_size: thread pool size
@@ -134,26 +143,35 @@ class Entrypoint:
         self.log_buffer_size = log_buffer_size
         self.log_buffering = log_buffering
         self.log_config = log_config
+        self.log_date_format = log_date_format
         self.log_flush_interval = log_flush_interval
         self.log_format = log_format
         self.log_level = log_level
         self.policy = policy
         self.pool_size = pool_size
-        self.services = services
+        self.__services = set(services)
         self.shutting_down = False
         self.pre_start = self.PRE_START.copy()
         self.post_start = self.POST_START.copy()
         self.pre_stop = self.PRE_STOP.copy()
         self.post_stop = self.POST_STOP.copy()
+        self._lock = asyncio.Lock()
 
         if self.log_config:
             aiomisc_log.basic_config(
                 level=self.log_level,
                 log_format=self.log_format,
+                date_format=log_date_format
             )
 
         if self._loop is not None:
-            set_current_loop(self._loop)
+            EVENT_LOOP.set(self._loop)
+
+        CURRENT_ENTRYPOINT.set(self)
+
+    @property
+    def services(self) -> Iterable[Service]:
+        return tuple(self.__services)
 
     async def closing(self) -> None:
         # Lazy initialization because event loop might be not exists
@@ -171,7 +189,7 @@ class Entrypoint:
                 debug=self._debug,
             )
             self._loop_owner = True
-            set_current_loop(self._loop)
+            EVENT_LOOP.set(self._loop)
         return self._loop
 
     def __del__(self) -> None:
@@ -195,6 +213,7 @@ class Entrypoint:
             basic_config(
                 level=self.log_level,
                 log_format=self.log_format,
+                date_format=self.log_date_format,
                 buffered=False,
             )
 
@@ -260,6 +279,27 @@ class Entrypoint:
 
         return None
 
+    async def start_services(self, *svc: Service) -> None:
+        await self.pre_start.call(entrypoint=self, services=svc)
+        try:
+            await asyncio.gather(*[self._start_service(s) for s in svc])
+        finally:
+            await self.post_start.call(entrypoint=self, services=svc)
+            for s in svc:
+                self.__services.add(s)
+
+    async def stop_services(
+        self, *svc: Service, exc: Optional[Exception] = None,
+    ) -> None:
+        await self.pre_stop.call(entrypoint=self, services=svc)
+
+        try:
+            await asyncio.gather(*[s.stop(exc) for s in svc])
+        finally:
+            for s in svc:
+                self.__services.remove(s)
+            await self.post_stop.call(entrypoint=self, services=svc)
+
     async def _cancel_background_tasks(self) -> None:
         tasks = asyncio_all_tasks(self._loop)
         current_task = asyncio_current_task(self.loop)
@@ -270,7 +310,7 @@ class Entrypoint:
             self._closing.set()
 
         tasks = []
-        for svc in self.services:
+        for svc in self.__services:
             try:
                 coro = svc.stop(exception)
             except TypeError as e:
@@ -293,6 +333,10 @@ class Entrypoint:
         await self.loop.shutdown_asyncgens()
 
 
+CURRENT_ENTRYPOINT: StrictContextVar[Entrypoint] = StrictContextVar(
+    "CURRENT_ENTRYPOINT",
+    RuntimeError("no current entrypoint is set"),
+)
 entrypoint = Entrypoint
 
 
