@@ -5,8 +5,10 @@ import logging.handlers
 import time
 import traceback
 from contextlib import suppress
+from functools import partial
 from socket import socket
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
+from weakref import finalize
 
 import aiomisc_log
 from aiomisc_log.enum import LogFormat, LogLevel
@@ -38,6 +40,16 @@ def _thread_flusher(
         time.sleep(flush_interval)
 
 
+def suppressor(
+    callback: Callable[..., None],
+    exceptions: Tuple[Type[BaseException], ...] = (Exception,),
+) -> Callable[..., None]:
+    def wrapper() -> None:
+        with suppress(*exceptions):
+            callback()
+    return wrapper
+
+
 def wrap_logging_handler(
     handler: logging.Handler,
     loop: Optional[asyncio.AbstractEventLoop] = None,
@@ -56,7 +68,9 @@ def wrap_logging_handler(
         ), no_return=True, statistic_name="logger",
     )
 
-    atexit.register(handler.flush)
+    at_exit_flusher = suppressor(handler.flush)
+    atexit.register(at_exit_flusher)
+    finalize(buffered_handler, partial(atexit.unregister, at_exit_flusher))
 
     return buffered_handler
 
@@ -80,7 +94,7 @@ class UnhandledLoopHook(aiomisc_log.UnhandledHookBase):
         ):
             value = transport.get_extra_info(key)
             if value:
-                extra["transport_{}".format(key)] = value
+                extra[f"transport_{key}"] = value
 
     def __call__(
         self, loop: asyncio.AbstractEventLoop,
@@ -126,8 +140,8 @@ def basic_config(
     log_format: Union[str, LogFormat] = LogFormat.default(),
     buffered: bool = True, buffer_size: int = 1024,
     flush_interval: Union[int, float] = 0.2,
-    loop: asyncio.AbstractEventLoop = None,
-    **kwargs: Any
+    loop: Optional[asyncio.AbstractEventLoop] = None,
+    **kwargs: Any,
 ) -> None:
     loop = loop or asyncio.get_event_loop()
     unhandled_hook = UnhandledLoopHook()
@@ -150,7 +164,7 @@ def basic_config(
         level=level,
         log_format=log_format,
         handler_wrapper=wrap_handler,
-        **kwargs
+        **kwargs,
     )
 
     loop.set_exception_handler(unhandled_hook)
