@@ -27,10 +27,10 @@ class AIOHTTPService(Service):
     runner: BaseRunner
 
     def __init__(
-        self, address: Optional[str] = "localhost", port: int = None,
-        sock: socket.socket = None, shutdown_timeout: int = 5,
+        self, address: Optional[str] = "localhost", port: Optional[int] = None,
+        sock: Optional[socket.socket] = None, shutdown_timeout: int = 5,
         runner_kwargs: Optional[RunnerKwargsType] = None,
-        **kwds: Any
+        **kwds: Any,
     ):
 
         if not sock:
@@ -90,7 +90,7 @@ class AIOHTTPService(Service):
         self.site = await self.create_site()
         await self.site.start()
 
-    async def stop(self, exception: Exception = None) -> None:
+    async def stop(self, exception: Optional[Exception] = None) -> None:
         try:
             if self.site:
                 await self.site.stop()
@@ -101,15 +101,16 @@ class AIOHTTPService(Service):
 
 class AIOHTTPSSLService(AIOHTTPService):
     def __init__(
-        self, cert: PathOrStr, key: PathOrStr, ca: PathOrStr = None,
-        address: str = None, port: int = None, verify: bool = True,
-        sock: socket.socket = None, shutdown_timeout: int = 5,
-        require_client_cert: bool = False, **kwds: Any
+        self, cert: PathOrStr, key: PathOrStr, ca: Optional[PathOrStr] = None,
+        address: Optional[str] = None, port: Optional[int] = None,
+        verify: bool = True, sock: Optional[socket.socket] = None,
+        shutdown_timeout: int = 5, require_client_cert: bool = False,
+        **kwds: Any,
     ):
 
         super().__init__(
             address=address, port=port, sock=sock,
-            shutdown_timeout=shutdown_timeout, **kwds
+            shutdown_timeout=shutdown_timeout, **kwds,
         )
 
         self.__ssl_options = cert, key, ca, verify, require_client_cert
@@ -121,6 +122,6 @@ class AIOHTTPSSLService(AIOHTTPService):
             self.runner, self.socket,
             shutdown_timeout=self.shutdown_timeout,
             ssl_context=await self.loop.run_in_executor(
-                None, get_ssl_context, *self.__ssl_options
+                None, get_ssl_context, *self.__ssl_options,
             ),
         )
